import 'monaco-editor/esm/vs/language/typescript/monaco.contribution';
import * as monaco from 'monaco-editor/esm/vs/editor/editor.api';
import typescriptGlobal from '../node_modules/@types/node/globals.d.js';
import typescriptConsole from '../node_modules/@types/node/console.d.js';
import typescriptProcess from '../node_modules/@types/node/process.d.js';
import { registerWorkerLoader } from '../worker.js';

const global = `
declare global {
  /**
   * Read a line from stdin
   */
  function readline(): string;

  /**
   * Print a string to stdout
   * @deprecated Use console.log instead
   */
  function print(word: string): void;
}

// It needs to be a module
export {}
`;
const compilerOptions = {
    target: monaco.languages.typescript.ScriptTarget.ES2016,
    allowNonTsExtensions: true,
    moduleResolution: monaco.languages.typescript.ModuleResolutionKind.NodeJs,
    module: monaco.languages.typescript.ModuleKind.CommonJS,
    noEmit: true,
    lib: ['es2020']
};
monaco.languages.typescript.typescriptDefaults.setCompilerOptions(compilerOptions);
monaco.languages.typescript.typescriptDefaults.addExtraLib(global, 'global.d.ts');
monaco.languages.typescript.typescriptDefaults.addExtraLib(typescriptGlobal, 'node/globals.d.ts');
monaco.languages.typescript.typescriptDefaults.addExtraLib(typescriptConsole, 'node/console.d.ts');
monaco.languages.typescript.typescriptDefaults.addExtraLib(typescriptProcess, 'node/process.d.ts');
monaco.languages.typescript.javascriptDefaults.setCompilerOptions(compilerOptions);
monaco.languages.typescript.javascriptDefaults.addExtraLib(global, 'global.d.ts');
monaco.languages.typescript.javascriptDefaults.addExtraLib(typescriptGlobal, 'node/globals.d.ts');
monaco.languages.typescript.javascriptDefaults.addExtraLib(typescriptConsole, 'node/console.d.ts');
monaco.languages.typescript.javascriptDefaults.addExtraLib(typescriptProcess, 'node/process.d.ts');
registerWorkerLoader('typescript', () => new Worker(new URL('monaco-editor/esm/vs/language/typescript/ts.worker', import.meta.url)));
registerWorkerLoader('javascript', () => new Worker(new URL('monaco-editor/esm/vs/language/typescript/ts.worker', import.meta.url)));
