import getModelServiceOverride from 'vscode/service-override/model';
import getDialogsServiceOverride from 'vscode/service-override/dialogs';
import getConfigurationServiceOverride from 'vscode/service-override/configuration';
import getKeybindingsServiceOverride from 'vscode/service-override/keybindings';
import getTextmateServiceOverride from 'vscode/service-override/textmate';
import getThemeServiceOverride from 'vscode/service-override/theme';
import getLanguagesServiceOverride from 'vscode/service-override/languages';
import getAudioCueServiceOverride from 'vscode/service-override/audioCue';
import getPreferencesServiceOverride from 'vscode/service-override/preferences';
import getSnippetServiceOverride from 'vscode/service-override/snippets';
import getQuickAccessServiceOverride from 'vscode/service-override/quickaccess';
import getAccessibilityServiceOverride from 'vscode/service-override/accessibility';
import getEditorServiceOverride from 'vscode/service-override/editor';
import { initialize as initialize$1, StandaloneServices, ILogService, LogLevel } from 'vscode/services';
import { initialize as initialize$2 } from 'vscode/extensions';
import * as monaco from 'monaco-editor/esm/vs/editor/editor.api';
import EditorOpenHandlerRegistry from './tools/EditorOpenHandlerRegistry.js';
import 'vscode/ext-hosts/all';

const editorOpenHandlerRegistry = new EditorOpenHandlerRegistry();
let services = {
    ...getModelServiceOverride(),
    ...getDialogsServiceOverride(),
    ...getConfigurationServiceOverride(monaco.Uri.file('/tmp/project')),
    ...getKeybindingsServiceOverride(),
    ...getTextmateServiceOverride(),
    ...getThemeServiceOverride(),
    ...getLanguagesServiceOverride(),
    ...getAudioCueServiceOverride(),
    ...getPreferencesServiceOverride(),
    ...getSnippetServiceOverride(),
    ...getQuickAccessServiceOverride({
        isKeybindingConfigurationVisible: () => false,
        shouldUseGlobalPicker: () => false
    }),
    ...getEditorServiceOverride((model, input, sideBySide) => {
        return editorOpenHandlerRegistry.openCodeEditor(model, input, sideBySide);
    }),
    ...getAccessibilityServiceOverride()
};
function registerServices(newServices) {
    services = {
        ...services,
        ...newServices
    };
}
async function initialize() {
    // wait a short time for the services to be registered
    await new Promise(resolve => setTimeout(resolve, 0));
    await initialize$1(services);
    StandaloneServices.get(ILogService).setLevel(LogLevel.Off);
    await initialize$2();
}

export { editorOpenHandlerRegistry, initialize, registerServices };
