var typescriptGlobal = "// Declare \"static\" methods in Error\ninterface ErrorConstructor {\n    /** Create .stack property on a target object */\n    captureStackTrace(targetObject: object, constructorOpt?: Function): void;\n\n    /**\n     * Optional override for formatting stack traces\n     *\n     * @see https://v8.dev/docs/stack-trace-api#customizing-stack-traces\n     */\n    prepareStackTrace?: ((err: Error, stackTraces: NodeJS.CallSite[]) => any) | undefined;\n\n    stackTraceLimit: number;\n}\n\n/*-----------------------------------------------*\n *                                               *\n *                   GLOBAL                      *\n *                                               *\n ------------------------------------------------*/\n\n// For backwards compability\ninterface NodeRequire extends NodeJS.Require { }\ninterface RequireResolve extends NodeJS.RequireResolve { }\ninterface NodeModule extends NodeJS.Module { }\n\ndeclare var process: NodeJS.Process;\ndeclare var console: Console;\n\ndeclare var __filename: string;\ndeclare var __dirname: string;\n\ndeclare var require: NodeRequire;\ndeclare var module: NodeModule;\n\n// Same as module.exports\ndeclare var exports: any;\n\n/**\n * Only available if `--expose-gc` is passed to the process.\n */\ndeclare var gc: undefined | (() => void);\n\n//#region borrowed\n// from https://github.com/microsoft/TypeScript/blob/38da7c600c83e7b31193a62495239a0fe478cb67/lib/lib.webworker.d.ts#L633 until moved to separate lib\n/** A controller object that allows you to abort one or more DOM requests as and when desired. */\ninterface AbortController {\n    /**\n     * Returns the AbortSignal object associated with this object.\n     */\n\n    readonly signal: AbortSignal;\n    /**\n     * Invoking this method will set this object's AbortSignal's aborted flag and signal to any observers that the associated activity is to be aborted.\n     */\n    abort(reason?: any): void;\n}\n\n/** A signal object that allows you to communicate with a DOM request (such as a Fetch) and abort it if required via an AbortController object. */\ninterface AbortSignal extends EventTarget {\n    /**\n     * Returns true if this AbortSignal's AbortController has signaled to abort, and false otherwise.\n     */\n    readonly aborted: boolean;\n    readonly reason: any;\n    onabort: null | ((this: AbortSignal, event: Event) => any);\n}\n\ndeclare var AbortController: typeof globalThis extends {onmessage: any; AbortController: infer T}\n    ? T\n    : {\n        prototype: AbortController;\n        new(): AbortController;\n    };\n\ndeclare var AbortSignal: typeof globalThis extends {onmessage: any; AbortSignal: infer T}\n    ? T\n    : {\n        prototype: AbortSignal;\n        new(): AbortSignal;\n        abort(reason?: any): AbortSignal;\n        timeout(milliseconds: number): AbortSignal;\n    };\n//#endregion borrowed\n\n//#region ArrayLike.at()\ninterface RelativeIndexable<T> {\n    /**\n     * Takes an integer value and returns the item at that index,\n     * allowing for positive and negative integers.\n     * Negative integers count back from the last item in the array.\n     */\n    at(index: number): T | undefined;\n}\ninterface String extends RelativeIndexable<string> {}\ninterface Array<T> extends RelativeIndexable<T> {}\ninterface ReadonlyArray<T> extends RelativeIndexable<T> {}\ninterface Int8Array extends RelativeIndexable<number> {}\ninterface Uint8Array extends RelativeIndexable<number> {}\ninterface Uint8ClampedArray extends RelativeIndexable<number> {}\ninterface Int16Array extends RelativeIndexable<number> {}\ninterface Uint16Array extends RelativeIndexable<number> {}\ninterface Int32Array extends RelativeIndexable<number> {}\ninterface Uint32Array extends RelativeIndexable<number> {}\ninterface Float32Array extends RelativeIndexable<number> {}\ninterface Float64Array extends RelativeIndexable<number> {}\ninterface BigInt64Array extends RelativeIndexable<bigint> {}\ninterface BigUint64Array extends RelativeIndexable<bigint> {}\n//#endregion ArrayLike.at() end\n\n/**\n * @since v17.0.0\n *\n * Creates a deep clone of an object.\n */\ndeclare function structuredClone<T>(\n    value: T,\n    transfer?: { transfer: ReadonlyArray<import('worker_threads').TransferListItem> },\n): T;\n\n/*----------------------------------------------*\n*                                               *\n*               GLOBAL INTERFACES               *\n*                                               *\n*-----------------------------------------------*/\ndeclare namespace NodeJS {\n    interface CallSite {\n        /**\n         * Value of \"this\"\n         */\n        getThis(): unknown;\n\n        /**\n         * Type of \"this\" as a string.\n         * This is the name of the function stored in the constructor field of\n         * \"this\", if available.  Otherwise the object's [[Class]] internal\n         * property.\n         */\n        getTypeName(): string | null;\n\n        /**\n         * Current function\n         */\n        getFunction(): Function | undefined;\n\n        /**\n         * Name of the current function, typically its name property.\n         * If a name property is not available an attempt will be made to try\n         * to infer a name from the function's context.\n         */\n        getFunctionName(): string | null;\n\n        /**\n         * Name of the property [of \"this\" or one of its prototypes] that holds\n         * the current function\n         */\n        getMethodName(): string | null;\n\n        /**\n         * Name of the script [if this function was defined in a script]\n         */\n        getFileName(): string | null;\n\n        /**\n         * Current line number [if this function was defined in a script]\n         */\n        getLineNumber(): number | null;\n\n        /**\n         * Current column number [if this function was defined in a script]\n         */\n        getColumnNumber(): number | null;\n\n        /**\n         * A call site object representing the location where eval was called\n         * [if this function was created using a call to eval]\n         */\n        getEvalOrigin(): string | undefined;\n\n        /**\n         * Is this a toplevel invocation, that is, is \"this\" the global object?\n         */\n        isToplevel(): boolean;\n\n        /**\n         * Does this call take place in code defined by a call to eval?\n         */\n        isEval(): boolean;\n\n        /**\n         * Is this call in native V8 code?\n         */\n        isNative(): boolean;\n\n        /**\n         * Is this a constructor call?\n         */\n        isConstructor(): boolean;\n    }\n\n    interface ErrnoException extends Error {\n        errno?: number | undefined;\n        code?: string | undefined;\n        path?: string | undefined;\n        syscall?: string | undefined;\n    }\n\n    interface ReadableStream extends EventEmitter {\n        readable: boolean;\n        read(size?: number): string | Buffer;\n        setEncoding(encoding: BufferEncoding): this;\n        pause(): this;\n        resume(): this;\n        isPaused(): boolean;\n        pipe<T extends WritableStream>(destination: T, options?: { end?: boolean | undefined; }): T;\n        unpipe(destination?: WritableStream): this;\n        unshift(chunk: string | Uint8Array, encoding?: BufferEncoding): void;\n        wrap(oldStream: ReadableStream): this;\n        [Symbol.asyncIterator](): AsyncIterableIterator<string | Buffer>;\n    }\n\n    interface WritableStream extends EventEmitter {\n        writable: boolean;\n        write(buffer: Uint8Array | string, cb?: (err?: Error | null) => void): boolean;\n        write(str: string, encoding?: BufferEncoding, cb?: (err?: Error | null) => void): boolean;\n        end(cb?: () => void): this;\n        end(data: string | Uint8Array, cb?: () => void): this;\n        end(str: string, encoding?: BufferEncoding, cb?: () => void): this;\n    }\n\n    interface ReadWriteStream extends ReadableStream, WritableStream { }\n\n    interface RefCounted {\n        ref(): this;\n        unref(): this;\n    }\n\n    type TypedArray =\n        | Uint8Array\n        | Uint8ClampedArray\n        | Uint16Array\n        | Uint32Array\n        | Int8Array\n        | Int16Array\n        | Int32Array\n        | BigUint64Array\n        | BigInt64Array\n        | Float32Array\n        | Float64Array;\n    type ArrayBufferView = TypedArray | DataView;\n\n    interface Require {\n        (id: string): any;\n        resolve: RequireResolve;\n        cache: Dict<NodeModule>;\n        /**\n         * @deprecated\n         */\n        extensions: RequireExtensions;\n        main: Module | undefined;\n    }\n\n    interface RequireResolve {\n        (id: string, options?: { paths?: string[] | undefined; }): string;\n        paths(request: string): string[] | null;\n    }\n\n    interface RequireExtensions extends Dict<(m: Module, filename: string) => any> {\n        '.js': (m: Module, filename: string) => any;\n        '.json': (m: Module, filename: string) => any;\n        '.node': (m: Module, filename: string) => any;\n    }\n    interface Module {\n        /**\n         * `true` if the module is running during the Node.js preload\n         */\n        isPreloading: boolean;\n        exports: any;\n        require: Require;\n        id: string;\n        filename: string;\n        loaded: boolean;\n        /** @deprecated since v14.6.0 Please use `require.main` and `module.children` instead. */\n        parent: Module | null | undefined;\n        children: Module[];\n        /**\n         * @since v11.14.0\n         *\n         * The directory name of the module. This is usually the same as the path.dirname() of the module.id.\n         */\n        path: string;\n        paths: string[];\n    }\n\n    interface Dict<T> {\n        [key: string]: T | undefined;\n    }\n\n    interface ReadOnlyDict<T> {\n        readonly [key: string]: T | undefined;\n    }\n}\n";

export { typescriptGlobal as default };
